@@ -523,6 +523,10 @@ class SelectStatement(BaseCQLStatement):
                  limit=None,
                  allow_filtering=False):
 
+        """
+        :param where
+        :type where list of cqlengine.statements.WhereClause
+        """
         super(SelectStatement, self).__init__(
             table,
             consistency=consistency,
@@ -549,7 +553,7 @@ class SelectStatement(BaseCQLStatement):
         if self.order_by and not self.count:
             qs += ['ORDER BY {}'.format(', '.join(unicode(o) for o in self.order_by))]
 
-        if self.limit and not self.count:
+        if self.limit:
             qs += ['LIMIT {}'.format(self.limit)]
 
         if self.allow_filtering:
