@@ -1,13 +1,15 @@
 from datetime import datetime
 import time
+from unittest import TestCase, skipUnless
 from uuid import uuid1, uuid4
+import uuid
 
 from cqlengine.tests.base import BaseCassEngTestCase
-
+import mock
 from cqlengine.exceptions import ModelException
 from cqlengine import functions
-from cqlengine.management import create_table, drop_table
-from cqlengine.management import delete_table
+from cqlengine.management import sync_table, drop_table, sync_table
+from cqlengine.management import drop_table
 from cqlengine.models import Model
 from cqlengine import columns
 from cqlengine import query
@@ -18,6 +20,11 @@ from cqlengine import statements
 from cqlengine import operators
 
 
+from cqlengine.connection import get_cluster, get_session
+
+cluster = get_cluster()
+
+
 class TzOffset(tzinfo):
     """Minimal implementation of a timezone offset to help testing with timezone
     aware datetimes.
@@ -37,6 +44,7 @@ class TzOffset(tzinfo):
 
 
 class TestModel(Model):
+    __keyspace__ = 'test'
     test_id = columns.Integer(primary_key=True)
     attempt_id = columns.Integer(primary_key=True)
     description = columns.Text()
@@ -45,6 +53,7 @@ class TestModel(Model):
 
 
 class IndexedTestModel(Model):
+    __keyspace__ = 'test'
     test_id = columns.Integer(primary_key=True)
     attempt_id = columns.Integer(index=True)
     description = columns.Text()
@@ -53,6 +62,7 @@ class IndexedTestModel(Model):
 
 
 class TestMultiClusteringModel(Model):
+    __keyspace__ = 'test'
     one = columns.Integer(primary_key=True)
     two = columns.Integer(primary_key=True)
     three = columns.Integer(primary_key=True)
@@ -172,11 +182,11 @@ class BaseQuerySetUsage(BaseCassEngTestCase):
     @classmethod
     def setUpClass(cls):
         super(BaseQuerySetUsage, cls).setUpClass()
-        delete_table(TestModel)
-        delete_table(IndexedTestModel)
-        create_table(TestModel)
-        create_table(IndexedTestModel)
-        create_table(TestMultiClusteringModel)
+        drop_table(TestModel)
+        drop_table(IndexedTestModel)
+        sync_table(TestModel)
+        sync_table(IndexedTestModel)
+        sync_table(TestMultiClusteringModel)
 
         TestModel.objects.create(test_id=0, attempt_id=0, description='try1', expected_result=5, test_result=30)
         TestModel.objects.create(test_id=0, attempt_id=1, description='try2', expected_result=10, test_result=30)
@@ -234,6 +244,14 @@ class TestQuerySetCountSelectionAndIteration(BaseQuerySetUsage):
         q = TestModel.objects(TestModel.test_id == 0)
         assert q.count() == 4
 
+    def test_query_limit_count(self):
+        """ Tests that adding query with a limit affects the count as expected """
+        assert TestModel.objects.count() == 12
+
+        q = TestModel.objects(TestModel.test_id == 0).limit(2)
+        result = q.count()
+        self.assertEqual(2, result)
+
     def test_iteration(self):
         """ Tests that iterating over a query set pulls back all of the expected results """
         q = TestModel.objects(test_id=0)
@@ -361,6 +379,29 @@ class TestQuerySetCountSelectionAndIteration(BaseQuerySetUsage):
         """
 
 
+def test_non_quality_filtering():
+    class NonEqualityFilteringModel(Model):
+        __keyspace__ = 'test'
+        example_id = columns.UUID(primary_key=True, default=uuid.uuid4)
+        sequence_id = columns.Integer(primary_key=True)  # sequence_id is a clustering key
+        example_type = columns.Integer(index=True)
+        created_at = columns.DateTime()
+
+    drop_table(NonEqualityFilteringModel)
+    sync_table(NonEqualityFilteringModel)
+
+    # setup table, etc.
+
+    NonEqualityFilteringModel.create(sequence_id=1, example_type=0, created_at=datetime.now())
+    NonEqualityFilteringModel.create(sequence_id=3, example_type=0, created_at=datetime.now())
+    NonEqualityFilteringModel.create(sequence_id=5, example_type=1, created_at=datetime.now())
+
+    qA = NonEqualityFilteringModel.objects(NonEqualityFilteringModel.sequence_id > 3).allow_filtering()
+    num = qA.count()
+    assert num == 1, num
+
+
+
 class TestQuerySetOrdering(BaseQuerySetUsage):
 
     def test_order_by_success_case(self):
@@ -510,6 +551,7 @@ class TestQuerySetConnectionHandling(BaseQuerySetUsage):
 
 
 class TimeUUIDQueryModel(Model):
+    __keyspace__ = 'test'
     partition = columns.UUID(primary_key=True)
     time = columns.TimeUUID(primary_key=True)
     data = columns.Text(required=False)
@@ -519,12 +561,12 @@ class TestMinMaxTimeUUIDFunctions(BaseCassEngTestCase):
     @classmethod
     def setUpClass(cls):
         super(TestMinMaxTimeUUIDFunctions, cls).setUpClass()
-        create_table(TimeUUIDQueryModel)
+        sync_table(TimeUUIDQueryModel)
 
     @classmethod
     def tearDownClass(cls):
         super(TestMinMaxTimeUUIDFunctions, cls).tearDownClass()
-        delete_table(TimeUUIDQueryModel)
+        drop_table(TimeUUIDQueryModel)
 
     def test_tzaware_datetime_support(self):
         """Test that using timezone aware datetime instances works with the
@@ -647,3 +689,21 @@ class TestObjectsProperty(BaseQuerySetUsage):
         assert TestModel.objects._result_cache is None
 
 
+@skipUnless(cluster.protocol_version >= 2, "only runs against the cql3 protocol v2.0")
+def test_paged_result_handling():
+    # addresses #225
+    class PagingTest(Model):
+        id = columns.Integer(primary_key=True)
+        val = columns.Integer()
+    sync_table(PagingTest)
+
+    PagingTest.create(id=1, val=1)
+    PagingTest.create(id=2, val=2)
+
+    session = get_session()
+    with mock.patch.object(session, 'default_fetch_size', 1):
+        results = PagingTest.objects()[:]
+
+    assert len(results) == 2
+
+
